@@ -1111,13 +1111,7 @@ impl VisitMut for SimplifyExpr {
                             Some(Expr::Lit(..) | Expr::Ident(..)) => {}
                             _ => {
                                 tracing::debug!("Injecting `0` to preserve `this = undefined`");
-                                seq.exprs.insert(
-                                    0,
-                                    Box::new(Expr::Lit(Lit::Num(Number {
-                                        span: DUMMY_SP,
-                                        value: 0.0,
-                                    }))),
-                                );
+                                seq.exprs.insert(0, 0.0.into());
                             }
                         }
 
@@ -1339,10 +1333,7 @@ impl VisitMut for SimplifyExpr {
             match *expr {
                 Expr::Lit(Lit::Num(n)) if self.in_callee && n.value == 0.0 => {
                     if exprs.is_empty() {
-                        exprs.push(Box::new(Expr::Lit(Lit::Num(Number {
-                            span: DUMMY_SP,
-                            value: 0.0,
-                        }))));
+                        exprs.push(0.0.into());
 
                         tracing::trace!("expr_simplifier: Preserving first zero");
                     }
@@ -1352,10 +1343,7 @@ impl VisitMut for SimplifyExpr {
                     if exprs.is_empty() {
                         self.changed = true;
 
-                        exprs.push(Box::new(Expr::Lit(Lit::Num(Number {
-                            span: DUMMY_SP,
-                            value: 0.0,
-                        }))));
+                        exprs.push(0.0.into());
 
                         tracing::debug!("expr_simplifier: Injected first zero");
                     }
